@@ -267,9 +267,15 @@ class MyWhatify:
 
         return sens[alg]
 
+    # @classmethod
+    # def func_base(cls, func, file_id):
+    #     for id in file_id:
+    #         func(file_id)
+
     @classmethod
     def delete_data_source(cls, data_id):
         logging.info('deleting data Source data_id: ' + str(data_id))
+        # cls.delete_base(func=my_toolkit.Datasource.delete, file_id=data_id)
         my_toolkit.Datasource.delete(data_id)
 
     @classmethod
@@ -415,6 +421,11 @@ class MyWhatify:
                 ret_list = my_toolkit.Dataset.get_available_estimators(inter_level=interpt_level, id=dataset_id)
         return ret_list
 
+    @classmethod
+    def get_prediction_list(cls, prediction_name):
+        with allure.step('getting the prediction list for the prediction_name: ' + str(prediction_name)):
+            return my_toolkit.Prediction.list(search_term=prediction_name)['hits']
+
     @classmethod
     def get_prediction(cls, predict_id, len=None):
         with allure.step('getting prediction list for predict_id: ' + str(predict_id) + ' len: ' + str(len)):
